intelmq.bots.parsers.turris package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.parsers.turris package

## Submodules

## intelmq.bots.parsers.turris.parser module

`intelmq.bots.parsers.turris.parser.` `BOT`

  alias of `intelmq.bots.parsers.turris.parser.TurrisGreylistParserBot`

class `intelmq.bots.parsers.turris.parser.` `TurrisGreylistParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Parse the Turris Greylist feed

  `process`()

## Module contents